@@ -45,6 +45,10 @@ namespace DialogGeometries {
   KEY ID;
 }
 
+namespace FileDialogPaths {
+  KEY ID;
+}
+
 namespace Node {
   KEY ID;
 
@@ -94,6 +98,12 @@ namespace Feeds {
   KEY EnableTooltipsFeedsMessages;
   VALUE(bool) EnableTooltipsFeedsMessagesDef;
 
+  KEY StrikethroughDisabledFeeds;
+  VALUE(bool) StrikethroughDisabledFeedsDef;
+
+  KEY PauseFeedFetching;
+  VALUE(bool) PauseFeedFetchingDef;
+
   KEY AutoUpdateInterval;
   VALUE(int) AutoUpdateIntervalDef;
 
@@ -218,6 +228,9 @@ namespace Messages {
   KEY MultilineArticleList;
   VALUE(bool) MultilineArticleListDef;
 
+  KEY SwitchArticleListRtl;
+  VALUE(bool) SwitchArticleListRtlDef;
+
   KEY CustomTimeFormat;
   VALUE(QString) CustomTimeFormatDef;
 
@@ -355,6 +368,9 @@ namespace GUI {
   KEY MonochromeTrayIcon;
   VALUE(bool) MonochromeTrayIconDef;
 
+  KEY ColoredBusyTrayIcon;
+  VALUE(bool) ColoredBusyTrayIconDef;
+
   KEY UnreadNumbersInTrayIcon;
   VALUE(bool) UnreadNumbersInTrayIconDef;
 
@@ -413,6 +429,9 @@ namespace Network {
   KEY EnableHttp2;
   VALUE(bool) EnableHttp2Def;
 
+  KEY CustomUserAgent;
+  VALUE(QString) CustomUserAgentDef;
+
   KEY IgnoreAllCookies;
   VALUE(bool) IgnoreAllCookiesDef;
 } // namespace Network
